# Quick Reference

Objects Implemented:
- Manga
- Chapter

Requirements:
- aiohttp
- requests
- python >= 3.6

It has asynchronous support on practically everything! Check out the source here : https://repl.it/@thatonedev/mangadexpy

Better docs + Roadmap coming in v0.5.0

---

Questions? Comments? Feedback?
https://feedback.thatonedev.repl.co